==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/tests/scripts/t30300-test-system-mta.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS
TS=PASS

sudo rm -rf /tmp/kcov-root
sudo mkdir -p /tmp/kcov-root
sudo chown -R "$(id -un):$(id -gn)" /tmp/kcov-root /var/lock/msmtp /var/spool/msmtp

export USER=root

/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta | grep -qE "(($(id -u msmtp))?|($(id -u))){2}"
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Displayed mail queue as root"

TS=PASS
/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -H 1

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Unhold non-existant message"

TS=PASS
/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -s 1

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Cannot show non-existant message"

TS=PASS

/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -H ALL
QSNDMRC=$?
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Unhold ALL as root"

TS=PASS

/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -f
QSNDMRC=$?
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: flush queue root"

sudo rm -rf /var/spool/msmtp /var/lock/msmtp
sudo mkdir -p -m 1777 /var/spool/msmtp
sudo mkdir -p -m 1777 /var/lock/msmtp

# So we can test creation of per-user dirs

export MSMTP_MTA_SKIP_CONF=true
export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-real.rc

sudo cp /etc/msmtprc /etc/msmtprc.test.old
sudo cp $(pwd)/.msmtprc /etc/msmtprc

TS=PASS

echo "Subject: queuing mail
       
Via sendmail substitute" | /usr/sbin/msmtpq-ng-mta root
QSNDMRC=$?

# If not tempfail
if [ "$QSNDMRC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail to root succeeds (queuing that is)"

TS=PASS

sudo journalctl -t msmtpq-ng | grep -qE 'enqueued mail as.*( root )'
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail queued mail"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/tests/scripts/t30300-test-system-mta.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS
TS=PASS

sudo rm -rf /tmp/kcov-root
sudo mkdir -p /tmp/kcov-root
sudo chown -R "$(id -un):$(id -gn)" /tmp/kcov-root /var/lock/msmtp /var/spool/msmtp

export USER=root

/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta | grep -qE "(($(id -u msmtp))?|($(id -u))){2}"
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Displayed mail queue as root"

TS=PASS
/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -H 1

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Unhold non-existant message"

TS=PASS
/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -s 1

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Cannot show non-existant message"

TS=PASS

/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -H ALL
QSNDMRC=$?
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: Unhold ALL as root"

TS=PASS

/usr/local/bin/kcov --exclude-path=/usr/lib,/etc --exclude-pattern=msmtpq-ng-mta.rc,fakeroot-sysv,fake-flock --bash-handle-sh-invocation /tmp/kcov-root /usr/sbin/msmtpq-ng-queue-mta -f
QSNDMRC=$?
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi
echo "$TS: flush queue root"

sudo rm -rf /var/spool/msmtp /var/lock/msmtp
sudo mkdir -p -m 1777 /var/spool/msmtp
sudo mkdir -p -m 1777 /var/lock/msmtp

# So we can test creation of per-user dirs

export MSMTP_MTA_SKIP_CONF=true
export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-real.rc

sudo cp /etc/msmtprc /etc/msmtprc.test.old
sudo cp $(pwd)/tmp/.msmtprc /etc/msmtprc

sed -i -e '$a\MSMTP_QUEUE_FIRST=false' ./tmp/msmtpq-ng-real.rc

TS=PASS

echo "Subject: queuing mail
       
Via sendmail substitute" | /usr/sbin/msmtpq-ng-mta root
QSNDMRC=$?

# If not tempfail
if [ "$QSNDMRC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail to root succeeds (queuing that is)"

TS=PASS

sudo journalctl -t msmtpq-ng | grep -qE 'enqueued mail as.*( root )'
QSNDMRC=$?

if [ "$QSNDMRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail queued mail"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
